import React from 'react'

import { ErrorComponent } from '../../../../src/components/ErrorComponent'
import { type GetServerSideProps } from 'next'
import { serverSideTranslations } from 'next-i18next/serverSideTranslations'
import { useShow } from '@refinedev/core'
import { Show } from '@refinedev/mui'
import { Typography } from '@mui/material'
import CircularProgress from '@mui/material/CircularProgress'
import Box from '@mui/material/Box'

const ShowFDO = () => {
  const { queryResult: { isError, error, isLoading, data }, showId } = useShow({
    errorNotification: () => false,
    queryOptions: {
      retry: false
    }
  })

  if (isError) {
    console.log('error', error)
    return <ErrorComponent/>
  }

  return (
    <Show
      isLoading={isLoading}
      title={<Typography variant="h5">Custom Title</Typography>}
    >
      { isLoading && <Box sx={{ textAlign: 'center' }}><CircularProgress/></Box>}
    </Show>

  )
}

export default ShowFDO

export const getServerSideProps: GetServerSideProps<{}> = async (context) => {
  console.log('getServerSideProps', context)
  const data = undefined // TODO
  const translateProps = await serverSideTranslations(context.locale ?? 'en', [
    'common'
  ])

  return {
    notFound: true,
    props: {
      ...translateProps
    }
  }
}
